# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`qpid`](#qpid): === SSL parameters  $auth::                     Use SASL authentication  $ssl::                      Use SSL with Qpid  $ssl_port::          
* [`qpid::client`](#qpidclient): Handles Qpid client package installations and configuration
* [`qpid::router`](#qpidrouter): Handles Qpid dispatch router package installations and configuration
* [`qpid::tools`](#qpidtools): Class to ensure qpid tools package

_Private Classes_

* `qpid::client::params`: Default parameter values
* `qpid::config`: Handles Qpid configuration
* `qpid::install`: Handles Qpid install
* `qpid::params`: Default parameter values
* `qpid::router::config`: Handles Qpid Dispatch Router configuration
* `qpid::router::install`: Installs Qpid router packages
* `qpid::router::params`: Default router parameter values
* `qpid::router::service`: Handles Qpid Dispatch Router service
* `qpid::service`: Handles Qpid service

**Defined types**

* [`qpid::config::bind`](#qpidconfigbind): This define binds the queue with the correct messages
* [`qpid::config::exchange`](#qpidconfigexchange): This define ensures an exchange exists
* [`qpid::config::queue`](#qpidconfigqueue): This define ensures a queue exists
* [`qpid::config_cmd`](#qpidconfig_cmd): This define wraps the qpid-config command
* [`qpid::router::connector`](#qpidrouterconnector): Configure a qpid router connector
* [`qpid::router::link_route`](#qpidrouterlink_route): Configure a link route
* [`qpid::router::listener`](#qpidrouterlistener): Configure a qpid router listener
* [`qpid::router::log`](#qpidrouterlog): Configure qpid router logging
* [`qpid::router::ssl_profile`](#qpidrouterssl_profile): Configures an SSL profile for Qpid Dispatch Router

## Classes

### qpid

=== SSL parameters

$auth::                     Use SASL authentication

$ssl::                      Use SSL with Qpid

$ssl_port::                 SSL port to use

$ssl_cert_db::              The SSL cert database to use

$ssl_cert_password_file::   The SSL cert password file

$ssl_cert_name::            The SSL cert name

$ssl_require_client_auth::  Require client SSL authentication

$session_unacked::          buffer if the broker has a large number of sessions and the memory overhead is a problem

=== Advanced parameters

$max_connections::          Maximum number of connections to allow

$wcache_page_size::         The size (in KB) of the pages in the write page cache

$open_file_limit::          Limit number of open files - systemd distros only

$log_to_syslog::            Log to syslog or not

$interface::                Interface to listen on

$server_store::             Install a Qpid message store

$version::                  Package version to be installed

$config_file::              Location of qpid configuration file

$server_store_package::     Package name for the Qpid message store

$user_groups::              Additional user groups to add the qpidd user to

$server_packages::          List of server packages to install

$mgmt_pub_interval::        Controls the interval at which the broker sends
                            updated information (stats, etc.) to the management console.

$default_queue_limit::      Default maximum size for queues (in bytes)

$custom_settings::          Custom settings. Each entry will end up in the config file.
                            The settings with can't be set this way and will cause the
                            server to refuse to start up.

#### Parameters

The following parameters are available in the `qpid` class.

##### `version`

Data type: `String`



Default value: $qpid::params::version

##### `auth`

Data type: `Boolean`



Default value: $qpid::params::auth

##### `config_file`

Data type: `String`



Default value: $qpid::params::config_file

##### `acl_content`

Data type: `Optional[String]`



Default value: $qpid::params::acl_content

##### `acl_file`

Data type: `String`



Default value: $qpid::params::acl_file

##### `log_level`

Data type: `String`



Default value: $qpid::params::log_level

##### `log_to_syslog`

Data type: `Boolean`



Default value: $qpid::params::log_to_syslog

##### `interface`

Data type: `Optional[String]`



Default value: $qpid::params::interface

##### `server_store`

Data type: `Boolean`



Default value: $qpid::params::server_store

##### `server_store_package`

Data type: `String`



Default value: $qpid::params::server_store_package

##### `ssl`

Data type: `Boolean`



Default value: $qpid::params::ssl

##### `ssl_port`

Data type: `Integer[0, 65535]`



Default value: $qpid::params::ssl_port

##### `session_unacked`

Data type: `Optional[Integer[0]]`



Default value: $qpid::params::session_unacked

##### `ssl_cert_db`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: $qpid::params::ssl_cert_db

##### `ssl_cert_password_file`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: $qpid::params::ssl_cert_password_file

##### `ssl_cert_name`

Data type: `Optional[String]`



Default value: $qpid::params::ssl_cert_name

##### `ssl_require_client_auth`

Data type: `Optional[Boolean]`



Default value: $qpid::params::ssl_require_client_auth

##### `user_groups`

Data type: `Array[String]`



Default value: $qpid::params::user_groups

##### `server_packages`

Data type: `Array[String]`



Default value: $qpid::params::server_packages

##### `max_connections`

Data type: `Optional[Integer[1]]`



Default value: $qpid::params::max_connections

##### `wcache_page_size`

Data type: `Optional[Integer[1]]`



Default value: $qpid::params::wcache_page_size

##### `open_file_limit`

Data type: `Optional[Integer[1]]`



Default value: $qpid::params::open_file_limit

##### `mgmt_pub_interval`

Data type: `Optional[Integer[1]]`



Default value: $qpid::params::mgmt_pub_interval

##### `default_queue_limit`

Data type: `Optional[Integer[1]]`



Default value: $qpid::params::default_queue_limit

##### `custom_settings`

Data type: `Hash[String, Variant[String, Integer]]`



Default value: $qpid::params::custom_settings

### qpid::client

Handles Qpid client package installations and configuration

#### Parameters

The following parameters are available in the `qpid::client` class.

##### `version`

Data type: `String`

The version to ensure. Can also be installed, latest or absent.

Default value: $qpid::client::params::version

##### `config_file`

Data type: `Stdlib::Absolutepath`

Path to the configuration file

Default value: $qpid::client::params::config_file

##### `log_level`

Data type: `String`



Default value: $qpid::client::params::log_level

##### `ssl`

Data type: `Boolean`

Whether to enable SSL.

Default value: $qpid::client::params::ssl

##### `ssl_port`

Data type: `Integer[0, 65535]`

SSL port to connect to

Default value: $qpid::client::params::ssl_port

##### `ssl_cert_db`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the SSL certificate database

Default value: $qpid::client::params::ssl_cert_db

##### `ssl_cert_password_file`

Data type: `Optional[Stdlib::Absolutepath]`

Optional password for the file with the certificate database password

Default value: $qpid::client::params::ssl_cert_password_file

##### `ssl_cert_name`

Data type: `Optional[String]`

The name to use inside the certificate database

Default value: $qpid::client::params::ssl_cert_name

##### `client_packages`

Data type: `Array[String]`

Packages to install

Default value: $qpid::client::params::client_packages

### qpid::router

Handles Qpid dispatch router package installations and configuration

#### Parameters

The following parameters are available in the `qpid::router` class.

##### `router_id`

Data type: `Any`

Unique router ID

Default value: $qpid::router::params::router_id

##### `mode`

Data type: `Any`

Router mode

Default value: $qpid::router::params::router_mode

##### `config_file`

Data type: `Any`

Dispatch router config file location

Default value: $qpid::router::params::config_file

##### `router_packages`

Data type: `Any`

The package to be installed

Default value: $qpid::router::params::router_packages

##### `open_file_limit`

Data type: `Any`

Limit number of open files - systemd distros only

Default value: $qpid::router::params::open_file_limit

##### `worker_threads`

Data type: `Any`

Number of worker threads

Default value: $qpid::router::params::worker_threads

##### `hello_interval`

Data type: `Any`

Frequency in seconds of sending heartbeats from this router

Default value: $qpid::router::params::hello_interval

##### `hello_max_age`

Data type: `Any`

Timeout of heartbeat before connections are dropped

Default value: $qpid::router::params::hello_max_age

### qpid::tools

Class to ensure qpid tools package

## Defined types

### qpid::config::bind

This define binds the queue with the correct messages

#### Parameters

The following parameters are available in the `qpid::config::bind` defined type.

##### `queue`

Data type: `Any`

Name of the queue

##### `exchange`

Data type: `Any`

Name of the exchange the queue is on

##### `hostname`

Data type: `Any`

Hostname of the qpid broker

Default value: `undef`

##### `port`

Data type: `Any`

Port that qpid is listening on

Default value: `undef`

##### `ssl_cert`

Data type: `Any`

SSL cert to use for qpid-config commands

Default value: `undef`

##### `ssl_key`

Data type: `Any`

SSL key to use for qpid-config commands

Default value: `undef`

### qpid::config::exchange

This define ensures an exchange exists

#### Parameters

The following parameters are available in the `qpid::config::exchange` defined type.

##### `exchange`

Data type: `Any`

Name of the exchange

Default value: $title

##### `hostname`

Data type: `Any`

Hostname of the qpid broker

Default value: `undef`

##### `port`

Data type: `Any`

Port that qpid is listening on

Default value: `undef`

##### `ssl_cert`

Data type: `Any`

SSL cert to use for qpid-config commands

Default value: `undef`

##### `ssl_key`

Data type: `Any`

SSL key to use for qpid-config commands

Default value: `undef`

### qpid::config::queue

This define ensures a queue exists

#### Parameters

The following parameters are available in the `qpid::config::queue` defined type.

##### `queue`

Data type: `Any`

Name of the queue

Default value: $title

##### `hostname`

Data type: `Any`

Hostname of the qpid broker

Default value: `undef`

##### `port`

Data type: `Any`

Port that qpid is listening on

Default value: `undef`

##### `ssl_cert`

Data type: `Any`

SSL cert to use for qpid-config commands

Default value: `undef`

##### `ssl_key`

Data type: `Any`

SSL key to use for qpid-config commands

Default value: `undef`

### qpid::config_cmd

This define wraps the qpid-config command

#### Parameters

The following parameters are available in the `qpid::config_cmd` defined type.

##### `command`

Data type: `Any`

The qpid-config command including parameters to execute

##### `onlyif`

Data type: `Any`

The qpid-config command including parameters to check if $command should be
executed

Default value: `false`

##### `unless`

Data type: `Any`

The qpid-config command including parameters to check if $command should
not be executed. Ignored if $onlyif is specified

Default value: `false`

##### `hostname`

Data type: `Any`

The hostname to connect to

Default value: 'localhost'

##### `port`

Data type: `Any`

Port that qpid is listening on

Default value: `undef`

##### `ssl_cert`

Data type: `Any`

SSL cert to use for qpid-config commands

Default value: `undef`

##### `ssl_key`

Data type: `Any`

SSL key to use for qpid-config commands

Default value: `undef`

### qpid::router::connector

Configure a qpid router connector

#### Parameters

The following parameters are available in the `qpid::router::connector` defined type.

##### `host`

Data type: `String`

Host/address to listen on

Default value: '127.0.0.1'

##### `port`

Data type: `Integer[0, 65535]`

Port to listen on

Default value: 5672

##### `sasl_mech`

Data type: `Optional[String]`

SASL mechanism to use

Default value: 'ANONYMOUS'

##### `sasl_username`

Data type: `Optional[String]`

SASL username

Default value: `undef`

##### `sasl_password`

Data type: `Optional[String]`

SASL password

Default value: `undef`

##### `role`

Data type: `Optional[Enum['normal', 'inter-router', 'route-container']]`

Listener role

Default value: `undef`

##### `ssl_profile`

Data type: `Optional[String]`

SSL profile to use

Default value: `undef`

##### `idle_timeout`

Data type: `Optional[Integer[0]]`

Timeout in seconds

Default value: `undef`

##### `config_file`

Data type: `String`



Default value: $qpid::router::config_file

### qpid::router::link_route

Configure a link route

#### Parameters

The following parameters are available in the `qpid::router::link_route` defined type.

##### `direction`

Data type: `Enum['in', 'out']`

Direction when using asymmetric routing

##### `prefix`

Data type: `String`

Prefix to use

Default value: 'queue.'

##### `connection`

Data type: `Optional[String]`

Connector for this link route pattern

Default value: `undef`

##### `config_file`

Data type: `String`



Default value: $qpid::router::config_file

### qpid::router::listener

Configure a qpid router listener

#### Parameters

The following parameters are available in the `qpid::router::listener` defined type.

##### `ssl_profile`

Data type: `Optional[String]`

SSL profile to use

Default value: `undef`

##### `host`

Data type: `Optional[String]`

Host/address to listen on

Default value: `undef`

##### `port`

Data type: `Integer[0, 65535]`

Port to listen on

Default value: 5672

##### `sasl_mech`

Data type: `Optional[String]`

SASL mechanism to use

Default value: 'ANONYMOUS'

##### `role`

Data type: `Optional[Enum['normal', 'inter-router', 'route-container']]`

Listener role

Default value: `undef`

##### `idle_timeout`

Data type: `Optional[Integer[0]]`

Timeout in seconds

Default value: `undef`

##### `config_file`

Data type: `String`



Default value: $qpid::router::config_file

### qpid::router::log

Configure qpid router logging

#### Parameters

The following parameters are available in the `qpid::router::log` defined type.

##### `module`

Data type: `String`

Logging module to use

Default value: 'DEFAULT'

##### `level`

Data type: `String`

Logging level to use (e.g., debug+, info+)

Default value: 'info+'

##### `timestamp`

Data type: `Boolean`

Enable timestamps

Default value: `true`

##### `output`

Data type: `Variant[Stdlib::Absolutepath, Enum['syslog']]`

Log file location

Default value: '/var/log/qdrouterd.log'

##### `config_file`

Data type: `String`

The config file to use

Default value: $qpid::router::config_file

### qpid::router::ssl_profile

Configures an SSL profile for Qpid Dispatch Router

#### Parameters

The following parameters are available in the `qpid::router::ssl_profile` defined type.

##### `ca`

Data type: `Stdlib::Absolutepath`

Location of CA pem file

##### `cert`

Data type: `Stdlib::Absolutepath`

Location of certificate pem file

##### `key`

Data type: `Stdlib::Absolutepath`

Location of private key pem file

##### `ciphers`

Data type: `Optional[String]`

Enabled ciphers, in OpenSSL format

Default value: `undef`

##### `protocols`

Data type: `Optional[Array[String]]`

Enabled TLS protocols (e.g. TLSv1.1, TLSv1.2)

Default value: `undef`

##### `password`

Data type: `Optional[String]`

Password, if required

Default value: `undef`

##### `config_file`

Data type: `String`

The config file to use. This is an advanced parameter and normally doesn't
need to be set.

Default value: $qpid::router::config_file

